# Python Salesforce.com FrameWork

Python Salesforce.com FrameWork

| API Name           | Protocol            | Data Format       | Communication                                     |
|--------------------|---------------------|-------------------|---------------------------------------------------|
| REST API           | REST                | JSON, XML         | Synchronous                                       |
| SOAP API           | SOAP (WSDL)         | XML               | Synchronous                                       |
| Chatter REST API   | REST                | JSON, XML         | Synchronous (photos are processed,asynchronously) |
| User Interface API | REST                | JSON              | Synchronous                                       |
| Analytics REST API | REST                | JSON, XML         | Synchronous                                       |
| Bulk API           | REST                | CSV, JSON, XML    | Asynchronous                                      |
| Metadata API       | SOAP (WSDL)         | XML               | Asynchronous                                      |
| Streaming API      | Bayeux              | JSON              | Asynchronous (stream of data)                     |
| Apex REST API      | REST                | JSON, XML, Custom | Synchronous                                       |
| Apex SOAP API      | SOAP (WSDL)         | XML               | Synchronous                                       |
| Tooling API        | REST or SOAP (WSDL) | JSON, XML, Custom | Synchronous                                       |